# Token生成示例代码（Java）

Maven依赖：

```xml
<dependencies>
    <dependency>
        <groupId>io.jsonwebtoken</groupId>
        <artifactId>jjwt-api</artifactId>
        <version>0.11.5</version>
    </dependency>
    <dependency>
        <groupId>io.jsonwebtoken</groupId>
        <artifactId>jjwt-impl</artifactId>
        <version>0.11.5</version>
    </dependency>
    <dependency>
        <groupId>io.jsonwebtoken</groupId>
        <artifactId>jjwt-jackson</artifactId>
        <version>0.11.5</version>
    </dependency>
</dependencies>
```

示例代码：

``` java
import io.jsonwebtoken.*;
import io.jsonwebtoken.security.Keys;

import java.security.Key;
import java.util.Date;
import java.util.UUID;

public class ServerTokenDemo {

    public static String generateServerToken(String subject, String issuer, String secretKey, int expireSeconds) {
        Key key = Keys.hmacShaKeyFor(secretKey.getBytes());
        long nowMillis = System.currentTimeMillis();
        Date now = new Date(nowMillis);

        JwtBuilder builder = Jwts.builder()
                .setId(UUID.randomUUID().toString())
                .setSubject(subject)
                .setIssuer(issuer)
                .setIssuedAt(now)
                .setNotBefore(now)
                .setExpiration(new Date(nowMillis + expireSeconds * 1000L))
                .signWith(key, SignatureAlgorithm.HS256);

        return builder.compact();
    }

    public static Claims validateServerToken(String secretKey, String tokenString) throws JwtException {
        Key key = Keys.hmacShaKeyFor(secretKey.getBytes());

        return Jwts.parserBuilder()
                .setSigningKey(key)
                .build()
                .parseClaimsJws(tokenString)
                .getBody();
    }

    public static void main(String[] args) {
        String subject = "user_110";
        String issuer = "aihelp";
        String secretKey = "secret_59362f5481a04b2da21ea9c6a1750210";
        int expireSeconds = 86400;

        String token = generateServerToken(subject, issuer, secretKey, expireSeconds);
        System.out.println("生成的Token: " + token);

        try {
            Claims claims = validateServerToken(secretKey, token);
            System.out.println("Token验证成功: " + claims);
        } catch (JwtException e) {
            System.out.println("Token验证失败: " + e.getMessage());
        }
    }
}
```

