# Token生成示例代码（Python）

示例代码：

``` python
import jwt
import uuid
from datetime import datetime, timedelta

def generate_server_token(subject, issuer, secret_key, expire_seconds):
    now_time = datetime.utcnow()
    payload = {
        'jti': str(uuid.uuid4()),
        'sub': subject,
        'iss': issuer,
        'exp': now_time + timedelta(seconds=expire_seconds),
        'iat': now_time,
        'nbf': now_time
    }

    token = jwt.encode(payload, secret_key, algorithm='HS256')
    return token

def validate_server_token(secret_key, token_string):
    try:
        claims = jwt.decode(token_string, secret_key, algorithms=['HS256'])
        return claims, None
    except jwt.ExpiredSignatureError:
        return None, 'Token has expired'
    except jwt.InvalidTokenError:
        return None, 'Invalid token'

# Example usage
if __name__ == "__main__":
    subject = "user_110"
    issuer = "aihelp"
    secret_key = "secret_59362f5481a04b2da21ea9c6a1750210"
    expire_seconds = 86400

    token = generate_server_token(subject, issuer, secret_key, expire_seconds)
    print("生成的Token:", token)

    claims, err = validate_server_token(secret_key, token)
    if err:
        print("Token验证失败:", err)
    else:
        print("Token验证成功:", claims)
```

